@@ -1,4 +1,4 @@
-/* vi: ts=8 sts=4 sw=4
+/*
 
     kiconloader.cpp: An icon loader for KDE with theming functionality.
 
@@ -52,16 +52,6 @@
 
 #include <qplatformdefs.h> //for readlink
 
-namespace
-{
-// Used to make cache keys for icons with no group. Result type is QString*
-QString NULL_EFFECT_FINGERPRINT()
-{
-    return QStringLiteral("noeffect");
-}
-
-}
-
 /**
  * Function to convert an uint32_t to AARRGGBB hex values.
  *
@@ -228,6 +218,7 @@ void KIconLoaderPrivate::clear()
     mThemesInTree.clear();
 }
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(6, 5)
 void KIconLoaderPrivate::drawOverlays(const KIconLoader *iconLoader, KIconLoader::Group group, int state, QPixmap &pix, const QStringList &overlays)
 {
     if (overlays.isEmpty()) {
@@ -306,6 +297,7 @@ void KIconLoaderPrivate::drawOverlays(const KIconLoader *iconLoader, KIconLoader
         }
     }
 }
+#endif
 
 void KIconLoaderPrivate::_k_refreshIcons(int group)
 {
@@ -596,6 +588,14 @@ QString KIconLoaderPrivate::makeCacheKey(const QString &name,
     // The KSharedDataCache is shared so add some namespacing. The following code
     // uses QStringBuilder (new in Qt 4.6)
 
+    QString effectKey = QStringLiteral("noeffect");
+
+    if ((group == KIconLoader::Desktop || group == KIconLoader::Panel) && state == KIconLoader::ActiveState) {
+        effectKey = QStringLiteral("active");
+    } else if (state == KIconLoader::DisabledState && group >= 0 && group < KIconLoader::LastGroup) {
+        effectKey = QStringLiteral("disabled");
+    }
+
     /* clang-format off */
     return (group == KIconLoader::User ? QLatin1String("$kicou_") : QLatin1String("$kico_"))
             % name
@@ -605,7 +605,7 @@ QString KIconLoaderPrivate::makeCacheKey(const QString &name,
             % QString::number(scale, 'f', 1)
             % QLatin1Char('_')
             % overlays.join(QLatin1Char('_'))
-            % (group >= 0 ? mpEffect.fingerprint(group, state) : NULL_EFFECT_FINGERPRINT())
+            % effectKey
             % QLatin1Char('_')
             % paletteId(colors)
             % (q->theme() && q->theme()->followsColorScheme() && state == KIconLoader::SelectedState ? QStringLiteral("_selected") : QString());
@@ -1113,8 +1113,13 @@ QPixmap KIconLoader::loadScaledIcon(const QString &_name,
         img = d->createIconImage(path, size, scale, static_cast<KIconLoader::States>(state), usedColors);
     }
 
-    if (group >= 0 && group < KIconLoader::LastGroup) {
-        img = d->mpEffect.apply(img, group, state);
+    // apply effects. When changing the logic here also adapt makeCacheKey
+    if ((group == KIconLoader::Desktop || group == KIconLoader::Panel) && state == KIconLoader::ActiveState) {
+        KIconEffect::toActive(img);
+    }
+
+    if (state == KIconLoader::DisabledState && group >= 0 && group < KIconLoader::LastGroup) {
+        KIconEffect::toDisabled(img);
     }
 
     if (favIconOverlay) {
@@ -1155,6 +1160,7 @@ QPixmap KIconLoader::loadScaledIcon(const QString &_name,
     return pix;
 }
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(6, 5)
 QMovie *KIconLoader::loadMovie(const QString &name, KIconLoader::Group group, int size, QObject *parent) const
 {
     QString file = moviePath(name, group, size);
@@ -1173,7 +1179,9 @@ QMovie *KIconLoader::loadMovie(const QString &name, KIconLoader::Group group, in
     }
     return movie;
 }
+#endif
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(6, 5)
 QString KIconLoader::moviePath(const QString &name, KIconLoader::Group group, int size) const
 {
     if (!d->mpGroups) {
@@ -1219,7 +1227,9 @@ QString KIconLoader::moviePath(const QString &name, KIconLoader::Group group, in
     }
     return file;
 }
+#endif
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(6, 5)
 QStringList KIconLoader::loadAnimated(const QString &name, KIconLoader::Group group, int size) const
 {
     QStringList lst;
@@ -1270,6 +1280,7 @@ QStringList KIconLoader::loadAnimated(const QString &name, KIconLoader::Group gr
     lst.sort();
     return lst;
 }
+#endif
 
 KIconTheme *KIconLoader::theme() const
 {
@@ -1393,10 +1404,12 @@ bool KIconLoader::hasContext(KIconLoader::Context context) const
     return false;
 }
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(6, 5)
 KIconEffect *KIconLoader::iconEffect() const
 {
     return &d->mpEffect;
 }
+#endif
 
 QPixmap KIconLoader::unknown()
 {
